/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2014 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.messenger.cli;

import javax.management.MBeanException;
import javax.management.MBeanServerConnection;
import org.apache.commons.cli.CommandLine;
import org.apache.commons.cli.Options;
import com.openexchange.auth.mbean.AuthenticatorMBean;
import com.openexchange.cli.AbstractMBeanCLI;
import com.openexchange.messenger.mbean.MessengerMBean;

/**
 * {@link CreateMessengerUserCLT}
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 * @since 7.6.0
 */
public class CreateMessengerUserCLT extends AbstractMBeanCLI<Void> {

    /**
     * Initializes a new {@link CreateMessengerUserCLT}.
     */
    public CreateMessengerUserCLT() {
        super();
    }

    /**
     * @param args
     */
    public static void main(String[] args) {
        new CreateMessengerUserCLT().execute(args);
    }

    @Override
    protected void checkOptions(CommandLine cmd) {
        checkOptions(cmd, null);
    }

    @Override
    protected void checkOptions(CommandLine cmd, Options options) {
        if (!cmd.hasOption('c')) {
            System.out.println("You must provide a context identifier.");
            if (null != options) {
                printHelp(options);
            }
            System.exit(-1);
            return;
        }
        if (!cmd.hasOption('u')) {
            System.out.println("You must provide a user identifier.");
            if (null != options) {
                printHelp(options);
            }
            System.exit(-1);
            return;
        }
        if (!cmd.hasOption('m')) {
            System.out.println("You must provide an E-Mail address.");
            if (null != options) {
                printHelp(options);
            }
            System.exit(-1);
            return;
        }
        if (!cmd.hasOption('f')) {
            System.out.println("You must provide a first name.");
            if (null != options) {
                printHelp(options);
            }
            System.exit(-1);
            return;
        }
        if (!cmd.hasOption('n')) {
            System.out.println("You must provide a last name.");
            if (null != options) {
                printHelp(options);
            }
            System.exit(-1);
            return;
        }
    }

    @Override
    protected boolean requiresAdministrativePermission() {
        return true;
    }

    @Override
    protected void administrativeAuth(String login, String password, CommandLine cmd, AuthenticatorMBean authenticator) throws MBeanException {
        authenticator.doAuthentication(login, password);
    }

    @Override
    protected String getFooter() {
        return null;
    }

    @Override
    protected String getName() {
        return "createmessengeruser";
    }

    @Override
    protected void addOptions(Options options) {
        options.addOption("c", "context", true, "A valid context identifier");
        options.addOption("u", "user", true, "A valid user identifier");
        options.addOption("m", "mail", true, "The user's E-Mail address");
        options.addOption("f", "firstname", true, "The user's first name");
        options.addOption("n", "lastname", true, "The user's last name");
    }

    @Override
    protected Void invoke(Options option, CommandLine cmd, MBeanServerConnection mbsc) throws Exception {
        final MessengerMBean messengerMBean = getMBean(mbsc, MessengerMBean.class, MessengerMBean.DOMAIN);

        final int contextId = parseInt('c', 0, cmd, option);
        final int userId = parseInt('u', 0, cmd, option);
        final String mail = cmd.getOptionValue('m');
        final String fn = cmd.getOptionValue('f');
        final String ln = cmd.getOptionValue('n');

        final String adminLogin = cmd.getOptionValue('A');
        final String adminPassword = cmd.getOptionValue('P');

        messengerMBean.createUser(userId, contextId, mail, fn, ln, adminLogin, adminPassword);

        System.out.println("Messenger user created.");
        return null;
    }

}
