/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2014 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.messenger.json.action;

import org.json.JSONException;
import org.json.JSONObject;
import com.openexchange.ajax.requesthandler.AJAXRequestResult;
import com.openexchange.config.cascade.ComposedConfigProperty;
import com.openexchange.config.cascade.ConfigView;
import com.openexchange.config.cascade.ConfigViewFactory;
import com.openexchange.exception.OXException;
import com.openexchange.messenger.MessengerAPI;
import com.openexchange.messenger.MessengerConfiguration;
import com.openexchange.messenger.MessengerExceptionCodes;
import com.openexchange.messenger.exception.MessengerException;
import com.openexchange.messenger.json.MessengerRequest;
import com.openexchange.messenger.session.StaticAuthSession;
import com.openexchange.server.ServiceLookup;
import com.openexchange.tools.session.ServerSession;


/**
 * {@link DeleteGuestUser}
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public class DeleteGuestUser extends MessengerAction {

    /**
     * Initializes a new {@link DeleteGuestUser}.
     * @param services
     */
    public DeleteGuestUser(ServiceLookup services) {
        super(services);
    }

    @Override
    protected AJAXRequestResult perform(final MessengerRequest messengerRequest) throws OXException, JSONException, MessengerException {
        final ServerSession session = messengerRequest.getSession();
        final int userId = session.getUserId();
        final int contextId = session.getContextId();

        final MessengerConfiguration configuration = MessengerConfiguration.getInstance();

        // Check if allowed
        {
            final boolean enabled;
            final ConfigViewFactory factory = getService(ConfigViewFactory.class);
            if (null == factory) {
                enabled = configuration.isGuestModeEnabled();
            } else {
                final ConfigView view = factory.getView(userId, contextId);
                final ComposedConfigProperty<Boolean> property = view.property("com.openexchange.messenger.guestMode.enabled", boolean.class);
                if (property.isDefined()) {
                    enabled = property.get().booleanValue();
                } else {
                    enabled = configuration.isGuestModeEnabled();
                }
            }
            if (false == enabled) {
                throw MessengerExceptionCodes.GUEST_INVITATION_DENIED.create(Integer.valueOf(userId), Integer.valueOf(contextId));
            }
        }

        // The guest's E-Mail address
        final String emailAddress = messengerRequest.checkParameter("mail");

        // pass to end point
        final MessengerAPI<StaticAuthSession> api = new MessengerAPI<StaticAuthSession>(new StaticAuthSession(configuration));
        try {
            api.deleteGuestUser(userId, contextId, emailAddress, null);
        } catch (final MessengerException e) {
            throw e;
        }

        return new AJAXRequestResult(new JSONObject(2).put("userName", emailAddress), "json");
    }

    @Override
    public String getAction() {
        return "delete_guest_user";
    }

}
