/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2020 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.messenger.provisioning.admin;

import com.openexchange.admin.rmi.dataobjects.User;
import com.openexchange.groupware.container.Contact;

/**
 * {@link ContactWrapper}
 * 
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public final class ContactWrapper {

    /**
     * Initializes a new {@link ContactWrapper}.
     */
    private ContactWrapper() {
        super();
    }

    public static Contact convert2Contact(final User rmiUser, final int contextId) {
        if (null == rmiUser) {
            return null;
        }

        final Contact contact = new Contact();
        contact.setAnniversary(rmiUser.getAnniversary());
        contact.setAssistantName(rmiUser.getAssistant_name());
        contact.setBirthday(rmiUser.getBirthday());
        contact.setBranches(rmiUser.getBranches());
        contact.setBusinessCategory(rmiUser.getBusiness_category());
        contact.setCategories(rmiUser.getCategories());
        contact.setCellularTelephone1(rmiUser.getCellular_telephone1());
        contact.setCellularTelephone2(rmiUser.getCellular_telephone2());
        contact.setCityBusiness(rmiUser.getCity_business());
        contact.setCityHome(rmiUser.getCity_home());
        contact.setCityOther(rmiUser.getCity_other());
        contact.setCommercialRegister(rmiUser.getCommercial_register());
        contact.setCompany(rmiUser.getCompany());
        contact.setContextId(contextId);
        contact.setCountryBusiness(rmiUser.getCountry_business());
        contact.setCountryHome(rmiUser.getCountry_home());
        contact.setCountryOther(rmiUser.getCountry_other());
        contact.setDepartment(rmiUser.getDepartment());
        contact.setDisplayName(rmiUser.getDisplay_name());
        contact.setEmail1(rmiUser.getEmail1());
        contact.setEmail2(rmiUser.getEmail2());
        contact.setEmail3(rmiUser.getEmail3());
        contact.setEmployeeType(rmiUser.getEmployeeType());
        contact.setFaxBusiness(rmiUser.getFax_business());
        contact.setFaxHome(rmiUser.getFax_home());
        contact.setFaxOther(rmiUser.getFax_other());
        contact.setGivenName(rmiUser.getGiven_name());
        contact.setInfo(rmiUser.getInfo());
        contact.setInstantMessenger1(rmiUser.getInstant_messenger1());
        contact.setInstantMessenger2(rmiUser.getInstant_messenger2());
        contact.setInternalUserId(rmiUser.getId().intValue());
        contact.setManagerName(rmiUser.getManager_name());
        contact.setMaritalStatus(rmiUser.getMarital_status());
        contact.setMiddleName(rmiUser.getMiddle_name());
        contact.setNickname(rmiUser.getNickname());
        contact.setNote(rmiUser.getNote());
        contact.setNumberOfChildren(rmiUser.getNumber_of_children());
        contact.setNumberOfEmployee(rmiUser.getNumber_of_employee());
        contact.setPosition(rmiUser.getPosition());
        contact.setPostalCodeBusiness(rmiUser.getPostal_code_business());
        contact.setPostalCodeHome(rmiUser.getPostal_code_home());
        contact.setPostalCodeOther(rmiUser.getPostal_code_other());
        contact.setProfession(rmiUser.getProfession());
        contact.setRoomNumber(rmiUser.getRoom_number());
        contact.setSalesVolume(rmiUser.getSales_volume());
        contact.setSpouseName(rmiUser.getSpouse_name());
        contact.setStateBusiness(rmiUser.getState_business());
        contact.setStateHome(rmiUser.getState_home());
        contact.setStateOther(rmiUser.getState_other());
        contact.setStreetBusiness(rmiUser.getStreet_business());
        contact.setStreetHome(rmiUser.getStreet_home());
        contact.setStreetOther(rmiUser.getStreet_other());
        contact.setSuffix(rmiUser.getSuffix());
        contact.setSurName(rmiUser.getSur_name());
        contact.setTaxID(rmiUser.getTax_id());
        contact.setTelephoneAssistant(rmiUser.getTelephone_assistant());
        contact.setTelephoneBusiness1(rmiUser.getTelephone_business1());
        contact.setTelephoneBusiness2(rmiUser.getTelephone_business2());
        contact.setTelephoneCallback(rmiUser.getTelephone_callback());
        contact.setTelephoneCar(rmiUser.getTelephone_car());
        contact.setTelephoneCompany(rmiUser.getTelephone_company());
        contact.setTelephoneHome1(rmiUser.getTelephone_home1());
        contact.setTelephoneHome2(rmiUser.getTelephone_home2());
        contact.setTelephoneIP(rmiUser.getTelephone_ip());
        contact.setTelephoneISDN(rmiUser.getTelephone_isdn());
        contact.setTelephoneOther(rmiUser.getTelephone_other());
        contact.setTelephonePager(rmiUser.getTelephone_pager());
        contact.setTelephonePrimary(rmiUser.getTelephone_primary());
        contact.setTelephoneRadio(rmiUser.getTelephone_radio());
        contact.setTelephoneTelex(rmiUser.getTelephone_telex());
        contact.setTelephoneTTYTTD(rmiUser.getTelephone_ttytdd());
        contact.setTitle(rmiUser.getTitle());
        contact.setURL(rmiUser.getUrl());
        return contact;
    }

}
