/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2020 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.messenger.provisioning.admin;

import org.slf4j.Logger;
import com.openexchange.messenger.MessengerAPI;
import com.openexchange.messenger.exception.MessengerException;
import com.openexchange.messenger.session.StaticAuthSession;

/**
 * {@link Invocable} - Delegates to {@link #doInvoke()}.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 * @param <R> The return type
 */
public abstract class Invocable<R> {

    private static final Logger LOGGER = org.slf4j.LoggerFactory.getLogger(Invocable.class);

    /** The connector */
    protected final MessengerAPI<StaticAuthSession> connector;

    /**
     * Initializes a new {@link Invocable}.
     */
    protected Invocable(final MessengerAPI<StaticAuthSession> connector) {
        super();
        this.connector = connector;
    }

    /**
     * Invokes it.
     *
     * @return The return value
     */
    public R invoke() {
        try {
            return doInvoke();
        } catch (final MessengerException e) {
            // throw new PluginException("A plug-in error occurred.", e);
            logError(e, LOGGER);
        } catch (final RuntimeException e) {
            // throw new PluginException("A runtime error occurred.", e);
            logError(e, LOGGER);
        }
        return null;
    }

    /**
     * Invokes the OX Messenger call.
     *
     * @return The return value
     * @throws MessengerException If an OX Messenger error occurs
     */
    protected abstract R doInvoke() throws MessengerException;

    /**
     * Logs specified exception.
     *
     * @param e The exception
     * @param logger The logger
     */
    protected abstract void logError(final Exception e, final Logger logger);

}
