/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2020 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.messenger.provisioning.admin;

import java.util.Set;
import com.openexchange.admin.plugins.OXUserPluginInterface;
import com.openexchange.admin.plugins.PluginException;
import com.openexchange.admin.rmi.dataobjects.Context;
import com.openexchange.admin.rmi.dataobjects.Credentials;
import com.openexchange.admin.rmi.dataobjects.User;
import com.openexchange.admin.rmi.dataobjects.UserModuleAccess;
import com.openexchange.messenger.exception.MessengerException;
import com.openexchange.messenger.provisioning.AbstractMessengerAccess;

/**
 * {@link MessengerProvisioningUserPlugin}
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public final class MessengerProvisioningUserPlugin extends AbstractMessengerAccess implements OXUserPluginInterface {

    /**
     * Initializes a new {@link MessengerProvisioningUserPlugin}.
     */
    public MessengerProvisioningUserPlugin() {
        super();
    }

    @Override
    public void create(final Context ctx, final User usr, final UserModuleAccess access, final Credentials cred) throws PluginException {
        // Invoke
        new Invocable<Void>(getConnector()) {

            @Override
            protected Void doInvoke() throws MessengerException {
                connector.createUser(new ContextWrapper(ctx), new UserWrapper(usr), ContactWrapper.convert2Contact(usr, ctx.getId().intValue()));
                return null;
            }

            @Override
            protected void logError(Exception e, org.slf4j.Logger logger) {
                logger.error("Failed to create user {} in context {} at messenger end point.", usr.getId(), ctx.getId(), e);
            }

        }.invoke();
    }

    @Override
    public void delete(final Context ctx, final User[] user, final Credentials cred) throws PluginException {
        final ContextWrapper context = new ContextWrapper(ctx);
        for (final User usr : user) {
            // Invoke
            new Invocable<Void>(getConnector()) {

                @Override
                protected Void doInvoke() throws MessengerException {
                    connector.deleteUser(context, new UserWrapper(usr), ContactWrapper.convert2Contact(usr, ctx.getId().intValue()));
                    return null;
                }

                @Override
                protected void logError(Exception e, org.slf4j.Logger logger) {
                    logger.error("Failed to delete user {} in context {} at messenger end point.", usr.getId(), ctx.getId(), e);
                }

            }.invoke();

        }
    }

    @Override
    public void change(final Context ctx, final User usrdata, final Credentials auth) throws PluginException {
        // TODO: Check for dropped "messenger" capability
    }

    @Override
    public User[] getData(final Context ctx, final User[] users, final Credentials cred) {
        // pass-through
        return users;
    }

    @Override
    public boolean canHandleContextAdmin() {
        return true;
    }

    @Override
    public void changeCapabilities(final Context ctx, final User user, final Set<String> capsToAdd, final Set<String> capsToRemove, final Set<String> capsToDrop, final Credentials auth) throws PluginException {
        // TODO: Check for dropped "messenger" capability
    }

    public void changeMailAddressPersonal(Context ctx, User user, String personal, Credentials auth) throws PluginException {
        // TODO Auto-generated method stub
    }

    @Override
    public void changeModuleAccess(final Context ctx, final User user, final String access_combination_name, final Credentials auth) throws PluginException {
        // TODO: Check for dropped "messenger" capability
    }

    @Override
    public void changeModuleAccess(final Context ctx, final User user, final UserModuleAccess moduleAccess, final Credentials auth) throws PluginException {
        // TODO: Check for dropped "messenger" capability
    }

}
