/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.messenger.exception;

import java.util.HashMap;
import java.util.Map;
import java.util.Map.Entry;
import org.json.JSONObject;

/**
 * {@link MessengerApiException}
 * 
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public class MessengerApiException extends MessengerException {

    private static final long serialVersionUID = 1363595387006504788L;

    private final int errorCode;
    private final Map<String, Object> properties;

    /**
     * Initializes a new {@link MessengerApiException}.
     * 
     * @param errorObject The JSON error object
     */
    public MessengerApiException(final JSONObject errorObject) {
        super(detailMessage(errorObject));
        errorCode = errorObject.optInt("code", 0);

        properties = new HashMap<String, Object>(4);
        for (final Entry<String, Object> entry : errorObject.entrySet()) {
            final String name = entry.getKey();
            if (!"msg".equals(name) && !"code".equals(name)) {
                properties.put(name, entry.getValue());
            }
        }
    }

    private static String detailMessage(final JSONObject errorObject) {
        if (null == errorObject) {
            return "Unknown";
        }
        final String msg = errorObject.optString("msg", null);
        final int code = errorObject.optInt("code", 0);

        final StringBuilder sb = new StringBuilder(32);
        boolean first = true;
        if (null != msg) {
            sb.append(msg);
            first = false;
        }
        if (0 != code) {
            if (first) {
                sb.append("Error code ").append(code);
                first = false;
            } else {
                sb.append(" (").append(code).append(')');
            }
        }
        return first ? "Unknown" : sb.toString();
    }

    /**
     * Gets the error code
     * 
     * @return The error code or <code>0</code> (zero) if not available
     */
    public int getErrorCode() {
        return errorCode;
    }

    /**
     * Gets the properties
     * 
     * @return The properties
     */
    public Map<String, Object> getProperties() {
        return properties;
    }

}
