/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2015 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.messenger.httpclient;

import java.io.IOException;
import org.apache.http.Header;
import org.apache.http.HttpException;
import org.apache.http.HttpRequest;
import org.apache.http.HttpRequestInterceptor;
import org.apache.http.auth.Credentials;
import org.apache.http.auth.UsernamePasswordCredentials;
import org.apache.http.impl.auth.BasicScheme;
import org.apache.http.impl.client.AbstractHttpClient;
import org.apache.http.protocol.HttpContext;
import com.openexchange.java.Charsets;


/**
 * Performs pre-emptive proxy authentication (limited to {@code Basic}).
 *
 * @author <a href="mailto:pascal.bleser@open-xchange.com">Pascal Bleser</a>
 * @since v7.6.2
 */
public final class PreemptiveBasicProxyAuthenticationInterceptor implements HttpRequestInterceptor {
    
    public static final void register(final PreemptiveBasicProxyAuthenticationInterceptor interceptor, final AbstractHttpClient client) {
        client.addRequestInterceptor(interceptor, 0);
    }

    public static final void register(final String username, final String password, final AbstractHttpClient client) {
        register(new PreemptiveBasicProxyAuthenticationInterceptor(username, password), client);
    }

    public static final void remove(final AbstractHttpClient client) {
        client.removeRequestInterceptorByClass(PreemptiveBasicProxyAuthenticationInterceptor.class);
    }
    
    // may be reused, is immutable
    private final Header header;

    public PreemptiveBasicProxyAuthenticationInterceptor(final String username, final String password) {
        super();
        
        final Credentials credentials;
        {
            if (username == null) {
                throw new IllegalArgumentException("username is null");
            }
            if (password == null) {
                throw new IllegalArgumentException("password is null");
            }
            credentials = new UsernamePasswordCredentials(username, username);
        }
        this.header = BasicScheme.authenticate(credentials, Charsets.US_ASCII.name(), true);
    }

    @Override
    public void process(final HttpRequest request, final HttpContext context) throws HttpException, IOException {
        request.addHeader(header);
    }
    
}
