/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2014 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.messenger.mbean;

import javax.management.MBeanException;


/**
 * {@link MessengerMBean} - The MBean for messenger component.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public interface MessengerMBean {

    /** The MBean's domain */
    public static final String DOMAIN = "com.openexchange.messenger";

    /**
     * Creates the specified user at messenger end point.
     *
     * @param userId The user identifier
     * @param contextId The context identifier
     * @param mailAddress The user's primary mail address
     * @param firstName The user's first name
     * @param lastName The user's last name
     * @param adminLogin The administrator login
     * @param adminPassword The administrator password
     * @throws MBeanException If create operation fails
     */
    void createUser(int userId, int contextId, String mailAddress, String firstName, String lastName, String adminLogin, String adminPassword) throws MBeanException;

    /**
     * Deletes the specified user from messenger end point.
     *
     * @param userId The user identifier
     * @param contextId The context identifier
     * @param adminLogin The administrator login
     * @param adminPassword The administrator password
     * @throws MBeanException If create operation fails
     */
    void deleteUser(int userId, int contextId, String adminLogin, String adminPassword) throws MBeanException;

    /**
     * Creates the specified context at messenger end point.
     *
     * @param contextId The context identifier
     * @param full <code>true</code> to create all users in given context; otherwise <code>false</code> to only create context administrator
     * @param adminLogin The administrator login
     * @param adminPassword The administrator password
     * @throws MBeanException If create operation fails
     */
    void createContext(int contextId, boolean full, String adminLogin, String adminPassword) throws MBeanException;

    /**
     * Deletes the specified context from messenger end point.
     *
     * @param contextId The context identifier
     * @param adminLogin The administrator login
     * @param adminPassword The administrator password
     * @throws MBeanException If create operation fails
     */
    void deleteContext(int contextId, String adminLogin, String adminPassword) throws MBeanException;

}
