/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2020 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.messenger.session;

import org.apache.http.auth.AuthScope;
import org.apache.http.auth.UsernamePasswordCredentials;
import org.apache.http.client.methods.HttpRequestBase;
import org.apache.http.impl.client.DefaultHttpClient;
import com.openexchange.messenger.MessengerConfiguration;
import com.openexchange.messenger.exception.MessengerException;

/**
 * {@link StaticAuthSession} - A {@link Session} based on basic authentication.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public class StaticAuthSession extends AbstractSession {

    private final MessengerConfiguration configuration;

    /**
     * Initializes a new {@link StaticAuthSession}.
     *
     * @param configuration The OX Messenger configuration providing static auth information
     */
    public StaticAuthSession(final MessengerConfiguration configuration) {
        super(null, configuration.isSecureSsl());
        this.configuration = configuration;
    }

    @Override
    public boolean isLinked() {
        return true;
    }

    @Override
    public void unlink() {
        // Nothing to do
    }

    @Override
    protected void modifyHttpClient(final DefaultHttpClient c) {
        super.modifyHttpClient(c);

        // Even basic auth is not needed by now
        if (false) {
            final UsernamePasswordCredentials creds = new UsernamePasswordCredentials(configuration.getUserName(), configuration.getPassword());
            c.getCredentialsProvider().setCredentials(AuthScope.ANY, creds);
        }
    }

    @Override
    public void sign(final HttpRequestBase request) throws MessengerException {
        // Nothing to do in case of static authentication
    }

    @Override
    public synchronized ProxyInfo getProxyInfo() {
        final String proxyHostname = configuration.getProxyHostname();
        if (proxyHostname != null) {
            final ProxyInfo pi;
            {
                final int proxyPort = configuration.getProxyPort();
                pi = new ProxyInfo(
                    proxyHostname,
                    proxyPort != Integer.MIN_VALUE ? proxyPort : -1,
                    configuration.getProxyUsername(),
                    configuration.getProxyPassword()
                );
            }
            return pi;
        } else {
            return super.getProxyInfo();
        }
    }

}
